@@ -127,7 +127,7 @@ PROTO_FOLDER = "program_folder"
 PROTO_GROUP = "group"
 PROTO_INSTEON = "insteon"
 PROTO_INT_VAR = "integer_variable"
-PROTO_NETWORK_RESOURCE = "network"
+PROTO_NETWORK = "network"
 PROTO_NODE_SERVER = "node_server"
 PROTO_PROGRAM = "program"
 PROTO_STATE_VAR = "state_variable"
@@ -184,6 +184,7 @@ URL_STATUS = "status"
 URL_SUBFOLDERS = "subfolders"
 URL_VARIABLES = "vars"
 URL_ZWAVE = "zwave"
+URL_PROFILE_NS = "profiles/ns"
 
 VAR_INTEGER = "1"
 VAR_STATE = "2"
